PacketType

Enum PacketType 

pub enum PacketType {
    None,
    ESP_PACKET_TYPE_EVENT,
    ESP_PRIV_EVENT_INIT,
    Hci(HciPkt),
}

Variants



None



ESP_PACKET_TYPE_EVENT

It appears that this is only used from the Slave



ESP_PRIV_EVENT_INIT

It appears that this is always the type sent by the host.



Hci(HciPkt)

Implementations

Source

impl PacketType

pub fn val(&self) -> u8

pub fn from_byte(b: u8) -> Result<Self, EspError>